@@ -221,8 +221,8 @@ df_to_char <- function(df){
 #' @importFrom utils head
 
 print.safety_summary <- function(x,...){
-  old_scipen <- options("scipen")
-  on.exit( options(scipen=old_scipen))
+  old_options <- options()
+  on.exit( options(old_options))
   options(scipen=999)
   cat("Group-Level Statistics\n\n")
   print(x$GROUP)
