@@ -36,9 +36,13 @@ test_that("three groups",{
     dplyr::mutate(group="Other")
   safety3 <- rbind(safety,other)
   stats3 <- safety_summary(safety3, exposed=c("Experimental"=60,"Control"=67, "Other"=67))
-  relative_risk(stats3)
+  rr <- relative_risk(stats3)
   rr_tab <- relative_risk_table(stats3, type="non_serious")
   expect_equal(ncol(rr_tab),4)
-}
+  
+  expect_no_error( rr |> order_filter())
+  
+  
+  }
 )
 
